# <a id="about-icinga2"></a> About icinga2apic

icinga2apic is a [Python](http://www.python.org) module to interact with the [Icinga 2 RESTful API](https://www.icinga.com/docs/icinga2/latest/doc/12-icinga2-api/).

# Features

1. [basic and certificate auth](doc/2-authentication.md)
1. [config file support](doc/2-authentication.md#-config-file)
1. [objects (zone support)](doc/3-objects.md)
1. [actions](doc/4-actions.md)
1. [events](doc/5-events.md)
1. [status](doc/6-status.md)

# Developing

1. Code cleanup
1. Tests
1. Configuration Management

# Usage

See the [doc](doc) directory.
